@@ -21,6 +21,8 @@ __PACKAGE__->add_columns(
   { data_type => "text", is_nullable => 1 },
   "index",
   { data_type => "text[]", is_nullable => 1, default_value => \"'{}'::text[]" },
+  "num_children",
+  { data_type => "integer", is_nullable => 0, default_value => \'0' },
 );
 __PACKAGE__->set_primary_key("oid");
 
